==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebOverlayOutletDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebOverlayOutletDirectiveDescription } from "./WebOverlayOutletDirectiveDescription";
/**
 * @hidden
 */
var WebOverlayOutletDirectiveDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebOverlayOutletDirectiveDescriptionMetadata, _super);
    function WebOverlayOutletDirectiveDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebOverlayOutletDirectiveDescriptionMetadata.b = function (a) {
        if (WebOverlayOutletDirectiveDescriptionMetadata.a == null) {
            WebOverlayOutletDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebOverlayOutletDirectiveDescriptionMetadata.c(WebOverlayOutletDirectiveDescriptionMetadata.a);
        }
        if (a.j(WebOverlayOutletDirectiveDescriptionMetadata.a)) {
            return;
        }
        a.y(WebOverlayOutletDirectiveDescriptionMetadata.a);
    };
    WebOverlayOutletDirectiveDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:OverlayOutletDirective");
        a.item("__packageNameWC", "String:grids");
    };
    WebOverlayOutletDirectiveDescriptionMetadata.d = function (a) {
        WebOverlayOutletDirectiveDescriptionMetadata.b(a);
        a.aa("WebOverlayOutletDirective", function () { return new WebOverlayOutletDirectiveDescription(); });
        a.z("WebOverlayOutletDirective", WebOverlayOutletDirectiveDescriptionMetadata.a);
    };
    WebOverlayOutletDirectiveDescriptionMetadata.$t = markType(WebOverlayOutletDirectiveDescriptionMetadata, 'WebOverlayOutletDirectiveDescriptionMetadata');
    WebOverlayOutletDirectiveDescriptionMetadata.a = null;
    return WebOverlayOutletDirectiveDescriptionMetadata;
}(Base));
export { WebOverlayOutletDirectiveDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebOverlayOutletDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebOverlayOutletDirectiveDescription } from "./WebOverlayOutletDirectiveDescription";
/**
 * @hidden
 */
var WebOverlayOutletDirectiveDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebOverlayOutletDirectiveDescriptionMetadata, _super);
    function WebOverlayOutletDirectiveDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebOverlayOutletDirectiveDescriptionMetadata.b = function (a) {
        if (WebOverlayOutletDirectiveDescriptionMetadata.a == null) {
            WebOverlayOutletDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebOverlayOutletDirectiveDescriptionMetadata.c(WebOverlayOutletDirectiveDescriptionMetadata.a);
        }
        if (a.k(WebOverlayOutletDirectiveDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebOverlayOutletDirectiveDescriptionMetadata.a);
    };
    WebOverlayOutletDirectiveDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:OverlayOutletDirective");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__skipSuffix", "Boolean");
    };
    WebOverlayOutletDirectiveDescriptionMetadata.d = function (a) {
        WebOverlayOutletDirectiveDescriptionMetadata.b(a);
        a.ac("WebOverlayOutletDirective", function () { return new WebOverlayOutletDirectiveDescription(); });
        a.ab("WebOverlayOutletDirective", WebOverlayOutletDirectiveDescriptionMetadata.a);
    };
    WebOverlayOutletDirectiveDescriptionMetadata.$t = markType(WebOverlayOutletDirectiveDescriptionMetadata, 'WebOverlayOutletDirectiveDescriptionMetadata');
    WebOverlayOutletDirectiveDescriptionMetadata.a = null;
    return WebOverlayOutletDirectiveDescriptionMetadata;
}(Base));
export { WebOverlayOutletDirectiveDescriptionMetadata };
